@@ -3,28 +3,29 @@ Uses the `Noembed <https://noembed.com/>`_ oEmbed service to embed (almost)
 arbitrary URLs. Depends on `requests <https://docs.python-requests.org>`_.
 """
 
+import json
 from hashlib import md5
 
+import requests
+from content_editor.admin import ContentEditorInline
 from django import forms
 from django.core.cache import cache
 from django.db import models
 from django.utils.html import mark_safe
 from django.utils.translation import gettext, gettext_lazy as _
 
-import requests
-from content_editor.admin import ContentEditorInline
-
 
 __all__ = (
     "External",
     "ExternalInline",
+    "NoembedValidationForm",
     "oembed_json",
     "oembed_html",
     "render_external",
 )
 
 
-def oembed_json(url, *, cache_failures=True):
+def oembed_json(url, *, cache_failures=True, force_refresh=False, params=None):
     """
     Asks `Noembed <https://noembed.com/>`_ for the embedding HTML code for
     arbitrary URLs. Sites supported include YouTube, Vimeo, Twitter and many
@@ -43,17 +44,20 @@ def oembed_json(url, *, cache_failures=True):
     The return value is always a dictionary, but it may be empty.
     """
     # Thundering herd problem etc...
-    key = "oembed-url-%s-data" % md5(url.encode("utf-8")).hexdigest()
-    data = cache.get(key)
+    p = {"url": url, "nowrap": "on", "maxwidth": 1200, "maxheight": 800}
+    if params:
+        p.update(params)
+    key = (
+        "oembed-url-%s-data"
+        % md5(json.dumps(p, sort_keys=True).encode("utf-8")).hexdigest()
+    )
+
+    data = None if force_refresh else cache.get(key)
     if data is not None:
         return data
 
     try:
-        data = requests.get(
-            "https://noembed.com/embed",
-            params={"url": url, "nowrap": "on", "maxwidth": 1200, "maxheight": 800},
-            timeout=2,
-        ).json()
+        data = requests.get("https://noembed.com/embed", params=p, timeout=2).json()
     except (requests.ConnectionError, requests.ReadTimeout):
         # Connection failed? Hopefully temporary, try again soon.
         timeout = 60
@@ -71,14 +75,14 @@ def oembed_json(url, *, cache_failures=True):
     return {}
 
 
-def oembed_html(url, *, cache_failures=True):
+def oembed_html(url, **kwargs):
     """
     Wraps :func:`~feincms3.plugins.external.oembed_json`, but only returns
     the HTML part of the OEmbed response.
 
     The return value is always either a HTML fragment or an empty string.
     """
-    return oembed_json(url, cache_failures=cache_failures).get("html", "")
+    return oembed_json(url, **kwargs).get("html", "")
 
 
 def render_external(plugin, **kwargs):
@@ -95,9 +99,9 @@ def render_external(plugin, **kwargs):
 
     html = oembed_html(plugin.url)
     if "youtube.com" in html:
-        html = '<div class="responsive-embed widescreen youtube">%s</div>' % (html,)
+        html = f'<div class="responsive-embed widescreen youtube">{html}</div>'
     elif "vimeo.com" in html:
-        html = '<div class="responsive-embed widescreen vimeo">%s</div>' % (html,)
+        html = f'<div class="responsive-embed widescreen vimeo">{html}</div>'
     return mark_safe(html)
 
 
@@ -107,18 +111,43 @@ class External(models.Model):
     """
 
     url = models.URLField(_("URL"))
+    alternative_text = models.CharField(
+        _("alternative text"),
+        help_text=_("Describe the contents, e.g. for screenreaders."),
+        max_length=1000,
+        blank=True,
+    )
+    caption = models.CharField(_("caption"), blank=True, max_length=1000)
 
     class Meta:
         abstract = True
         verbose_name = _("external content")
 
     def __str__(self):
-        return self.url
+        return self.caption or self.url
 
 
-class ExternalForm(forms.ModelForm):
+class NoembedValidationForm(forms.ModelForm):
     """
     Tries fetching the oEmbed code for the given URL when cleaning form data
+
+    This isn't active by default. If you want to validate URLs you should use
+    the following snippet:
+
+    .. code-block:: python
+
+        from app.pages import models
+        from feincms3 import plugins
+
+        class SomeAdmin(...):
+            inlines = [
+                ...
+                plugins.external.ExternalInline.create(
+                    model=models.External,
+                    form=plugins.external.NoembedValidationForm,
+                ),
+                ...
+            ]
     """
 
     def clean(self):
@@ -132,9 +161,4 @@ class ExternalForm(forms.ModelForm):
 
 
 class ExternalInline(ContentEditorInline):
-    """
-    Content editor inline using the ``ExternalForm`` to verify whether the
-    given URL is embeddable using oEmbed or not.
-    """
-
-    form = ExternalForm
+    button = '<span class="material-icons">movie_creation</span>'
