@@ -3,11 +3,12 @@ Provides an image plugin with support for setting the primary point of
 interest. This is very useful especially when cropping images. Depends on
 `django-imagefield <https://django-imagefield.readthedocs.io>`__.  """
 
+import os
+
+from content_editor.admin import ContentEditorInline
 from django.db import models
 from django.utils.html import format_html
 from django.utils.translation import gettext_lazy as _
-
-from content_editor.admin import ContentEditorInline
 from imagefield.fields import ImageField, PPOIField
 
 
@@ -35,6 +36,13 @@ class Image(models.Model):
         _("image height"), blank=True, null=True, editable=False
     )
     ppoi = PPOIField(_("primary point of interest"))
+    alternative_text = models.CharField(
+        _("alternative text"),
+        help_text=_("Describe the contents, e.g. for screenreaders."),
+        max_length=1000,
+        blank=True,
+    )
+    caption = models.CharField(_("caption"), blank=True, max_length=1000)
 
     class Meta:
         abstract = True
@@ -42,7 +50,7 @@ class Image(models.Model):
         verbose_name_plural = _("images")
 
     def __str__(self):
-        return self.image.name
+        return self.caption or os.path.basename(self.image.name)
 
 
 class ImageInline(ContentEditorInline):
@@ -50,7 +58,7 @@ class ImageInline(ContentEditorInline):
     Image inline
     """
 
-    pass
+    button = '<span class="material-icons">insert_photo</span>'
 
 
 def render_image(plugin, **kwargs):
